@@ -69,7 +69,7 @@ from snaptrade_client.apis.paths.performance_custom import PerformanceCustom
 PathToApi = typing_extensions.TypedDict(
     'PathToApi',
     {
-        PathValues.SOLIDUS: Root,
+        PathValues._: Root,
         PathValues.SNAP_TRADE_ACCEPT_DISCLAIMER: SnapTradeAcceptDisclaimer,
         PathValues.SNAP_TRADE_LIST_USERS: SnapTradeListUsers,
         PathValues.SNAP_TRADE_REGISTER_USER: SnapTradeRegisterUser,
@@ -138,7 +138,7 @@ PathToApi = typing_extensions.TypedDict(
 
 path_to_api = PathToApi(
     {
-        PathValues.SOLIDUS: Root,
+        PathValues._: Root,
         PathValues.SNAP_TRADE_ACCEPT_DISCLAIMER: SnapTradeAcceptDisclaimer,
         PathValues.SNAP_TRADE_LIST_USERS: SnapTradeListUsers,
         PathValues.SNAP_TRADE_REGISTER_USER: SnapTradeRegisterUser,
